@@ -34,7 +34,7 @@ def main():
     parser.add_argument("snrEnd", help="snr file ending", type=int)
 
 # optional inputs
-    parser.add_argument("-plt", "--plt", default=None, help="ploting is boolean now. Default is True", type=str)
+    parser.add_argument("-plt", "--plt", default=None, help="plt to screen (True or False)", type=str)
     parser.add_argument("-fr", "--fr", default=None, type=int, help="try -fr 1 for GPS L1 only, or -fr 101 for Glonass L1")
     parser.add_argument("-ampl", "--ampl", default=None, type=float, help="try -ampl 5-6 for minimum spectral amplitude")
     parser.add_argument("-sat", "--sat", default=None, type=int, help="allow individual satellite")
@@ -63,6 +63,15 @@ def main():
     doy= args.doy
     snr_type = args.snrEnd
 
+
+    if len(str(year)) != 4:
+        print('Year must have four characters: ', year)
+        sys.exit()
+
+    if (doy > 366):
+        print('doy cannot be larger than 366: ', year)
+        sys.exit()
+
 # allow people to have an extension to the output file name so they can run different analysis strategies
 # this is undocumented and only for Kristine at the moment
     if args.extension == None:
@@ -74,12 +83,9 @@ def main():
     print(lsp)
     # now check the overrides to the json instructions
     print('plt argument', args.plt)
-    if (args.plt != None):
-        if args.plt == 'True':
-            lsp['plt_screen'] = True
-        if args.plt == 'False':
-            lsp['plt_screen'] = False
-    else:
+    if args.plt == 'True':
+        lsp['plt_screen'] = True
+    elif args.plt == 'False':
         lsp['plt_screen'] = False
 
     if (args.delTmax != None):
@@ -113,9 +119,6 @@ def main():
     else:
         year_end = args.year_end
 
-
-
-
 # default will be to overwrite
     if args.nooverwrite == None:
         lsp['overwriteResults'] = True
