@@ -26,7 +26,7 @@ def main():
     parser.add_argument("snrEnd", help="snr ending", type=str)
     parser.add_argument("orbType", help="orbit type, nav or sp3 (igs,igr,gbm,jax,sha,wum,grg)", type=str)
 # optional arguments
-    parser.add_argument("-rate", default=None, metavar='low',type=str, help="sample rate: low or high")
+    parser.add_argument("-rate", default='low', metavar='low',type=str, help="sample rate: low or high, only unavco")
     parser.add_argument("-dec", default=0, type=int, help="decimate (seconds)")
     parser.add_argument("-nolook", default='False', metavar='False', type=str, help="True means only use RINEX files on local machine")
     parser.add_argument("-fortran", default='True', metavar='True',type=str, help="True means use Fortran RINEX translators ")
@@ -47,6 +47,12 @@ def main():
         print('Illegal input - Station must have 4 or 9 characters')
         sys.exit()
     year = args.year
+
+
+    if len(str(year)) != 4:
+        print('Year must be four characters long: ', year)
+        sys.exit()
+
     doy1= args.doy1
     snrt = args.snrEnd # string
     isnr = int(snrt)
@@ -70,10 +76,8 @@ def main():
     else:
         nol = False
 
-    if args.rate == None:
-        rate = 'low'
-    else:
-        rate = 'high'
+    # default is set to low.  pick high for 1sec files from unavco
+    rate = args.rate
 
     if args.doy_end == None:
         doy2 = doy1
